@@ -31,6 +31,7 @@ __all__ = [
     "cpu_vnni_compatible",
     "cpu_avx2_compatible",
     "cpu_avx512_compatible",
+    "cpu_quantization_compatible",
     "print_hardware_capability",
 ]
 
@@ -99,17 +100,24 @@ class architecture(dict):
     @property
     def num_threads(self):
         """
-        :return: the total number of hyperthreads available on the current machine
+        :return: the total number of hyperthreads on the current machine
         """
         return self.threads_per_socket * self.num_sockets
 
     @property
     def num_physical_cores(self):
         """
-        :return: the total number of cores available on the current machine
+        :return: the total number of cores on the current machine
         """
         return self.cores_per_socket * self.num_sockets
 
+    @property
+    def num_available_physical_cores(self):
+        """
+        :return: the total number of cores available on the current machine
+        """
+        return self.available_cores_per_socket * self.available_sockets
+
 
 @_Memoize
 def _parse_arch_bin() -> architecture:
@@ -206,6 +214,15 @@ def cpu_avx2_compatible() -> bool:
     return cpu_architecture().isa == "avx2" or cpu_avx512_compatible()
 
 
+def cpu_quantization_compatible() -> bool:
+    """
+    :return: True if the current cpu has the AVX2 or AVX512 instruction sets,
+        used for running quantized neural networks performantly.
+        (AVX2 < AVX512 < VNNI)
+    """
+    return cpu_avx2_compatible() or cpu_avx512_compatible()
+
+
 def cpu_details() -> Tuple[int, str, bool]:
     """
     Detect the CPU details on linux systems
@@ -224,7 +241,7 @@ def cpu_details() -> Tuple[int, str, bool]:
     """
     arch = cpu_architecture()
 
-    return arch.num_physical_cores, arch.isa, arch.vnni
+    return arch.num_available_physical_cores, arch.isa, arch.vnni
 
 
 def print_hardware_capability():
@@ -233,13 +250,19 @@ def print_hardware_capability():
     model performance within the DeepSparse Engine.
     """
     arch = cpu_architecture()
+
+    quantized_flag = "TRUE (emulated)" if cpu_quantization_compatible() else "FALSE"
+    if cpu_vnni_compatible():
+        quantized_flag = "TRUE"
+
     message = (
-        f"{arch.vendor} CPU detected with {arch.num_physical_cores} cores. "
-        f"({arch.num_sockets} sockets with {arch.cores_per_socket} cores each)\n"
+        f"{arch.vendor} CPU detected with {arch.num_available_physical_cores} cores. "
+        f"({arch.available_sockets} sockets with "
+        f"{arch.available_cores_per_socket} cores each)\n"
         "DeepSparse FP32 model performance supported: "
         f"{cpu_avx2_compatible() or cpu_avx512_compatible()}.\n"
         "DeepSparse INT8 (quantized) model performance supported: "
-        f"{cpu_vnni_compatible()}.\n\n"
+        f"{quantized_flag}.\n\n"
     )
 
     if cpu_avx2_compatible() and not cpu_avx512_compatible():
@@ -248,5 +271,13 @@ def print_hardware_capability():
             "but inference time will be slower compared with an AVX-512 system.\n\n"
         )
 
+    if cpu_quantization_compatible() and not cpu_vnni_compatible():
+        message += (
+            "Non VNNI system detected. Performance speedups for INT8 (quantized) "
+            "models is available, but will be slower compared with a VNNI system. "
+            "Set NM_FAST_VNNI_EMULATION=True in the environment to enable faster "
+            "emulated inference which may have a minor effect on accuracy.\n\n"
+        )
+
     message += f"Additional CPU info: {arch}"
     print(message)
